# Security Policy

## Introduction

I take the security of the EasyTL library very seriously. I appreciate your efforts to responsibly disclose your findings and will make every effort to acknowledge your contributions.

Please note: Public disclosure of the vulnerability without prior agreement is not recommended, as it could put the wider user community at risk.

## Reporting a Vulnerability

Please report (suspected) security vulnerabilities to **[Bikatr7@proton.me](mailto:Bikatr7@proton.me)**. You should receive a response within 48 hours. If the issue is confirmed, I will release a patch as soon as possible depending on the complexity but typically within a few days.

### What to include in a security report

- The version of EasyTL you are using
- A description of the vulnerability
- The potential impact of the vulnerability
- Steps to reproduce or proof of concept

This information will help me to swiftly resolve potential vulnerabilities.

## Encrypted Communication

If you believe that your message needs to be encrypted, you can use this PGP Key so that only I can read it.
```plaintext
-----BEGIN PGP PUBLIC KEY BLOCK-----


my3Q2eo2ITAF
=EP+L
-----END PGP PUBLIC KEY BLOCK-----
```

## Policy on Security Updates

I will keep you informed of the progress towards fixing the vulnerability and announce the patched version once it is available.

## Acknowledgements

Individuals who report security vulnerabilities responsibly will be acknowledged in the project documentation. If you would like to be acknowledged, please include a name or alias in your report.